@@ -14,11 +14,10 @@ from .plotting import figure, get_cc
 from .fit import Fitter
 from .crypt import Crypt
 from .ecdf import ecdf
-from .cached_loader import CachedLoader
 from .shaper import Shaper
 from .bernstein import Bernstein
+from .iterify import iterify
 from .dataframe_tools import (
-    date_diff,
     slugify,
 )
 
@@ -27,7 +26,6 @@ from .outlier_tools import (
     kill_outliers_sigma_edit
 )
 from .utils import (
-    ChattyDict,
     mute_warnings,
     print_error,
     screen_width_full,
@@ -40,7 +38,6 @@ from .utils import (
 
 # alias for ease of remembering the name
 warnings_mute = mute_warnings
-DictChatty = ChattyDict
 
 # For backwards compatibility alias Fit to Fitter
 class Fit(Fitter):
